==> jc-1.4.0.tar.gz: java/awt/JobAttributes__24MultipleDocumentHandlingType.h <==
// public final class java.awt.JobAttributes$MultipleDocumentHandlingType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class b043be3de72b01d java_awt_JobAttributes__24MultipleDocumentHandlingType
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_JobAttributes__24MultipleDocumentHandlingType_H_
#define _JC_java_awt_JobAttributes__24MultipleDocumentHandlingType_H_

// Forward structure declarations
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_refs	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_refs;
typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_nonrefs	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_nonrefs;
typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$refs	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$refs;
typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$nonrefs	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$nonrefs;
typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object;

typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$fields_struct	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$fields_struct;
typedef const struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vmethods	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vmethods;
typedef const struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtable	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtable;
typedef const struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtype	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtype;

// Class fields structure
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$fields_struct {
	_jc_object_array	*NAMES;
	struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object	*SEPARATE__5fDOCUMENTS__5fCOLLATED__5fCOPIES;
	struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object	*SEPARATE__5fDOCUMENTS__5fUNCOLLATED__5fCOPIES;
};
extern _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$fields_struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$class_fields;

// Constructors
extern void _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object *, jint);

// Static methods
extern void _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vmethods {
};

// Vtable
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vmethods	java_awt_JobAttributes__24MultipleDocumentHandlingType;
};

// Vtype
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtype {
	_jc_type			type;
	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$refs {
    _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_refs	java_awt_JobAttributes__24MultipleDocumentHandlingType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_nonrefs	java_awt_JobAttributes__24MultipleDocumentHandlingType;
};

// Object instance structure
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object {
	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtype	*vtype;
	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtype _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_JobAttributes__24MultipleDocumentHandlingType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$class_object;

#endif	/* _JC_java_awt_JobAttributes__24MultipleDocumentHandlingType_H_ */

==> jc-1.4.6.tar.gz: java/awt/JobAttributes__24MultipleDocumentHandlingType.h <==
// public final class java.awt.JobAttributes$MultipleDocumentHandlingType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class b043be3de72b01d java_awt_JobAttributes__24MultipleDocumentHandlingType
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_JobAttributes__24MultipleDocumentHandlingType_H_
#define _JC_java_awt_JobAttributes__24MultipleDocumentHandlingType_H_

// Forward structure declarations
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_refs	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_refs;
typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_nonrefs	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_nonrefs;
typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$refs	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$refs;
typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$nonrefs	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$nonrefs;
typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object;

typedef struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$fields_struct	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$fields_struct;
typedef const struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vmethods	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vmethods;
typedef const struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtable	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtable;
typedef const struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtype	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtype;

// Class fields structure
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$fields_struct {
	_jc_object_array	*NAMES;
	struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object	*SEPARATE__5fDOCUMENTS__5fCOLLATED__5fCOPIES;
	struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object	*SEPARATE__5fDOCUMENTS__5fUNCOLLATED__5fCOPIES;
};
extern _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$fields_struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$class_fields;

// Constructors
extern void _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object *, jint) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vmethods {
};

// Vtable
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vmethods	java_awt_JobAttributes__24MultipleDocumentHandlingType;
};

// Vtype
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtype {
	_jc_type			type;
	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$refs {
    _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_refs	java_awt_JobAttributes__24MultipleDocumentHandlingType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$sub_nonrefs	java_awt_JobAttributes__24MultipleDocumentHandlingType;
};

// Object instance structure
struct _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$object {
	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtype	*vtype;
	_jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$vtype _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_JobAttributes__24MultipleDocumentHandlingType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_JobAttributes__24MultipleDocumentHandlingType$class_object;

#endif	/* _JC_java_awt_JobAttributes__24MultipleDocumentHandlingType_H_ */
